bayespy.nodes.Wishart
=====================

.. currentmodule:: bayespy.nodes

.. autoclass:: Wishart

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Wishart.__init__
      ~Wishart.add_plate_axis
      ~Wishart.broadcasting_multiplier
      ~Wishart.delete
      ~Wishart.get_gradient
      ~Wishart.get_mask
      ~Wishart.get_moments
      ~Wishart.get_parameters
      ~Wishart.get_riemannian_gradient
      ~Wishart.get_shape
      ~Wishart.has_plotter
      ~Wishart.initialize_from_parameters
      ~Wishart.initialize_from_prior
      ~Wishart.initialize_from_random
      ~Wishart.initialize_from_value
      ~Wishart.load
      ~Wishart.logpdf
      ~Wishart.lower_bound_contribution
      ~Wishart.lowerbound
      ~Wishart.move_plates
      ~Wishart.observe
      ~Wishart.pdf
      ~Wishart.plot
      ~Wishart.random
      ~Wishart.save
      ~Wishart.set_parameters
      ~Wishart.set_plotter
      ~Wishart.show
      ~Wishart.unobserve
      ~Wishart.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Wishart.dims
      ~Wishart.plates
      ~Wishart.plates_multiplier
   
   